==============
pychemcurv.vis
==============

.. automodule:: pychemcurv.vis

.. figure:: img/vis.png
    :align: center


    Visualization of the pyramidalization angle using a color scale.

CurvatureViewer class
---------------------

.. autoclass:: pychemcurv.vis.CurvatureViewer
    :members:
